@@ -1,7 +1,7 @@
 package App::PMUtils;
 
-our $DATE = '2016-12-28'; # DATE
-our $VERSION = '0.66'; # VERSION
+our $DATE = '2017-02-01'; # DATE
+our $VERSION = '0.67'; # VERSION
 
 use 5.010001;
 
@@ -46,19 +46,19 @@ $SPEC{pmpath} = {
             cmdline_aliases => {P=>{}},
         },
         pm => {
-            schema => 'bool',
+            schema => ['int*', min=>0],
             default => 1,
         },
         pmc => {
-            schema => 'bool',
+            schema => ['int*', min=>0],
             default => 0,
         },
         pod => {
-            schema => 'bool',
+            schema => ['int*', min=>0],
             default => 0,
         },
         prefix => {
-            schema => 'bool',
+            schema => ['int*', min=>0],
             default => 0,
         },
         dir => {
@@ -188,7 +188,7 @@ App::PMUtils - Command-line utilities related to Perl modules
 
 =head1 VERSION
 
-This document describes version 0.66 of App::PMUtils (from Perl distribution App-PMUtils), released on 2016-12-28.
+This document describes version 0.67 of App::PMUtils (from Perl distribution App-PMUtils), released on 2017-02-01.
 
 =head1 SYNOPSIS
 
@@ -239,6 +239,8 @@ modules:
 
 =item * L<pmxs>
 
+=item * L<podlist>
+
 =item * L<podpath>
 
 =item * L<pwd2mod>
@@ -275,11 +277,11 @@ Absolutify each path.
 
 =item * B<module>* => I<array[perl::modname]>
 
-=item * B<pm> => I<bool> (default: 1)
+=item * B<pm> => I<int> (default: 1)
 
-=item * B<pmc> => I<bool> (default: 0)
+=item * B<pmc> => I<int> (default: 0)
 
-=item * B<pod> => I<bool> (default: 0)
+=item * B<pod> => I<int> (default: 0)
 
 =back
 
@@ -326,13 +328,13 @@ and it won't change directory if the module doesn't exist.
 
 =item * B<module>* => I<array[perl::modname]>
 
-=item * B<pm> => I<bool> (default: 1)
+=item * B<pm> => I<int> (default: 1)
 
-=item * B<pmc> => I<bool> (default: 0)
+=item * B<pmc> => I<int> (default: 0)
 
-=item * B<pod> => I<bool> (default: 0)
+=item * B<pod> => I<int> (default: 0)
 
-=item * B<prefix> => I<bool> (default: 0)
+=item * B<prefix> => I<int> (default: 0)
 
 =back
 
@@ -428,7 +430,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
